@@ -7,6 +7,7 @@ from pytype import utils
 from pytype.pyi import parser
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
+from pytype.tests import test_base
 import six
 
 import unittest
@@ -21,9 +22,7 @@ def get_builtins_source(python_version):
     return f.read()
 
 
-class _ParserTestBase(unittest.TestCase):
-
-  PYTHON_VERSION = (2, 7, 6)
+class _ParserTestBase(test_base.UnitTest):
 
   def check(self, src, expected=None, prologue=None, name=None,
             version=None, platform=None):
@@ -47,7 +46,7 @@ class _ParserTestBase(unittest.TestCase):
     Returns:
       The parsed pytd.TypeDeclUnit.
     """
-    version = version or self.PYTHON_VERSION
+    version = version or self.python_version
     src = textwrap.dedent(src).lstrip()
     ast = parser.parse_string(src, name=name, python_version=version,
                               platform=platform)
@@ -67,7 +66,7 @@ class _ParserTestBase(unittest.TestCase):
     """Check that parsing the src raises the expected error."""
     with self.assertRaises(parser.ParseError) as e:
       parser.parse_string(textwrap.dedent(src).lstrip(),
-                          python_version=self.PYTHON_VERSION)
+                          python_version=self.python_version)
     six.assertRegex(self, utils.message(e.exception), re.escape(message))
     self.assertEqual(expected_line, e.exception.line)
 
@@ -278,7 +277,7 @@ class ParserTest(_ParserTestBase):
 
   def test_conditional_nested_class(self):
     self.check("""
-      if sys.version_info >= (3, 6):
+      if sys.version_info < (3, 5):
         class A:
           class B: ...
     """, "")
@@ -430,7 +429,7 @@ class ParserTest(_ParserTestBase):
         this is not valid"""
     with self.assertRaises(parser.ParseError) as e:
       parser.parse_string(textwrap.dedent(src).lstrip(), filename="foo.py",
-                          python_version=self.PYTHON_VERSION)
+                          python_version=self.python_version)
     self.assertMultiLineEqual(textwrap.dedent("""
         File: "foo.py", line 2
           this is not valid
@@ -471,7 +470,7 @@ class ParserTest(_ParserTestBase):
         X = ... # type: ?
       y = bar.X.Baz
       z = X.Baz
-    """), name="foo", python_version=self.PYTHON_VERSION)
+    """), name="foo", python_version=self.python_version)
     self.assertEqual("foo.bar.X.Baz", ast.Lookup("foo.y").type.name)
     self.assertEqual("bar.X.Baz", ast.Lookup("foo.z").type.name)
 
@@ -586,7 +585,7 @@ class HomogeneousTypeTest(_ParserTestBase):
     """, """
       from typing import Tuple
 
-      def f() -> Tuple[nothing, ...]: ...
+      def f() -> Tuple[()]: ...
     """)
 
   def test_simple(self):
@@ -613,7 +612,7 @@ class NamedTupleTest(_ParserTestBase):
 
       _Tnamedtuple-foo-0 = TypeVar('_Tnamedtuple-foo-0', bound=`namedtuple-foo-0`)
 
-      class `namedtuple-foo-0`(Tuple[nothing, ...]):
+      class `namedtuple-foo-0`(Tuple[()]):
           __slots__ = []
           _asdict: Any
           __dict__: Any
@@ -655,8 +654,8 @@ class NamedTupleTest(_ParserTestBase):
     self.check("x = ...  # type: NamedTuple('foo', [('a', int,), ('b', str),])",
                expected)
 
+  # pylint: disable=line-too-long
   def test_dedup_basename(self):
-    # pylint: disable=line-too-long
     self.check("""
       x = ...  # type: NamedTuple('foo', [('a', int,)])
       y = ...  # type: NamedTuple('foo', [('b', str,)])""",
@@ -695,6 +694,7 @@ class NamedTupleTest(_ParserTestBase):
           def __new__(cls: Type[`_Tnamedtuple-foo-1`], b: str) -> `_Tnamedtuple-foo-1`: ...
           def __init__(self, *args, **kwargs) -> None: ...
         """)
+  # pylint: enable=line-too-long
 
   def test_assign_namedtuple(self):
     self.check("X = NamedTuple('X', [])", """
@@ -704,7 +704,7 @@ class NamedTupleTest(_ParserTestBase):
 
       _Tnamedtuple-X-0 = TypeVar('_Tnamedtuple-X-0', bound=`namedtuple-X-0`)
 
-      class `namedtuple-X-0`(Tuple[nothing, ...]):
+      class `namedtuple-X-0`(Tuple[()]):
           __slots__ = []
           _asdict: Any
           __dict__: Any
@@ -723,7 +723,7 @@ class NamedTupleTest(_ParserTestBase):
 
       _Tnamedtuple-X-0 = TypeVar('_Tnamedtuple-X-0', bound=`namedtuple-X-0`)
 
-      class `namedtuple-X-0`(Tuple[nothing, ...]):
+      class `namedtuple-X-0`(Tuple[()]):
           __slots__ = []
           _asdict: Any
           __dict__: Any
@@ -1382,7 +1382,7 @@ class IfTest(_ParserTestBase):
 
   def test_if_true(self):
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         x = ...  # type: int
       """, """
       x: int""")
@@ -1404,7 +1404,7 @@ class IfTest(_ParserTestBase):
 
   def test_else_ignored(self):
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         x = ...  # type: int
       else:
         y = ...  # type: str
@@ -1415,7 +1415,7 @@ class IfTest(_ParserTestBase):
     self.check("""
       if sys.version_info == (1, 2, 3):
         x = ...  # type: int
-      elif sys.version_info == (2, 7, 6):
+      elif sys.version_info >= (3, 5, 0):
         y = ...  # type: float
       else:
         z = ...  # type: str
@@ -1426,7 +1426,7 @@ class IfTest(_ParserTestBase):
     self.check("""
       if sys.version_info > (1, 2, 3):
         x = ...  # type: int
-      elif sys.version_info == (2, 7, 6):
+      elif sys.version_info >= (3, 5, 0):
         y = ...  # type: float
       else:
         z = ...  # type: str
@@ -1464,12 +1464,12 @@ class IfTest(_ParserTestBase):
         a = ...  # type: int
       if sys.version_info < (0, 0, 0) or sys.version_info >= (2, 0):
         b = ...  # type: int
-      if sys.version_info < (0, 0, 0) or sys.version_info > (3,):
+      if sys.version_info < (0, 0, 0) or sys.version_info > (4,):
         c = ...  # type: int
-      if sys.version_info >= (2, 0) or sys.version_info >= (2, 7):
+      if sys.version_info >= (2, 0) or sys.version_info >= (4, 7):
         d = ...  # type: int
       if (sys.platform == "windows" or sys.version_info < (0,) or
-          sys.version_info >= (2, 7)):
+          sys.version_info >= (3, 5)):
         e = ...  # type: int
     """, """
       a: int
@@ -1479,9 +1479,9 @@ class IfTest(_ParserTestBase):
 
   def test_if_and(self):
     self.check("""
-      if sys.version_info >= (2, 0) and sys.version_info < (3, 0):
+      if sys.version_info >= (3, 0) and sys.version_info < (4, 0):
         a = ...  # type: int
-      if sys.version_info >= (2, 0) and sys.version_info >= (3, 0):
+      if sys.version_info >= (3, 0) and sys.version_info >= (4, 0):
         b = ...  # type: int
     """, """
       a: int""")
@@ -1491,7 +1491,7 @@ class IfTest(_ParserTestBase):
 
   def test_conditional_import(self):
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         from foo import Processed
       else:
         from foo import Ignored
@@ -1499,7 +1499,7 @@ class IfTest(_ParserTestBase):
 
   def test_conditional_alias_or_constant(self):
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         x = Processed
       else:
         y = Ignored
@@ -1507,7 +1507,7 @@ class IfTest(_ParserTestBase):
 
   def test_conditional_class(self):
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         class Processed: ...
       else:
         class Ignored: ...
@@ -1526,7 +1526,7 @@ class IfTest(_ParserTestBase):
     # to the PEP 484 list class.
     self.check("""
       from typing import List
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         class Dict: ...
       else:
         class List: ...
@@ -1544,7 +1544,7 @@ class IfTest(_ParserTestBase):
     # The legacy parser did not handle this correctly - typevars are added
     # regardless of any conditions.
     self.check("""
-      if sys.version_info == (2, 7, 6):
+      if sys.version_info >= (3, 5, 0):
         T = TypeVar('T')
       else:
         F = TypeVar('F')
@@ -1565,9 +1565,9 @@ class ClassIfTest(_ParserTestBase):
   def test_conditional_constant(self):
     self.check("""
       class Foo:
-        if sys.version_info == (2, 7, 0):
+        if sys.version_info == (3, 4, 0):
           x = ...  # type: int
-        elif sys.version_info == (2, 7, 6):
+        elif sys.version_info >= (3, 5, 0):
           y = ...  # type: str
         else:
           z = ...  # type: float
@@ -1579,9 +1579,9 @@ class ClassIfTest(_ParserTestBase):
   def test_conditional_method(self):
     self.check("""
       class Foo:
-        if sys.version_info == (2, 7, 0):
+        if sys.version_info == (3, 4, 0):
           def a(self, x: int) -> str: ...
-        elif sys.version_info == (2, 7, 6):
+        elif sys.version_info >= (3, 5, 0):
           def b(self, x: int) -> str: ...
         else:
           def c(self, x: int) -> str: ...
@@ -1593,8 +1593,8 @@ class ClassIfTest(_ParserTestBase):
   def test_nested(self):
     self.check("""
       class Foo:
-        if sys.version_info > (2, 7, 0):
-          if sys.version_info == (2, 7, 6):
+        if sys.version_info > (3, 4, 0):
+          if sys.version_info >= (3, 5, 0):
             def b(self, x: int) -> str: ...
       """, """
       class Foo:
@@ -1604,21 +1604,21 @@ class ClassIfTest(_ParserTestBase):
   def test_no_import(self):
     self.check_error("""
       class Foo:
-        if sys.version_info > (2, 7, 0):
+        if sys.version_info > (3, 4, 0):
           import foo
     """, 3, "syntax error")
 
   def test_bad_alias(self):
     self.check_error("""
       class Foo:
-        if sys.version_info > (2, 7, 0):
+        if sys.version_info > (3, 4, 0):
           a = b
     """, 1, "Illegal value for alias 'a'")
 
   def test_no_class(self):
     self.check("""
       class Foo:
-        if sys.version_info <= (2, 7, 0):
+        if sys.version_info <= (3, 4, 0):
           class Bar: ...
     """, """
       class Foo: ...
@@ -1627,7 +1627,7 @@ class ClassIfTest(_ParserTestBase):
   def test_no_typevar(self):
     self.check_error("""
       class Foo:
-        if sys.version_info > (2, 7, 0):
+        if sys.version_info > (3, 4, 0):
           T = TypeVar('T')
     """, 3, "syntax error")
 
@@ -1636,6 +1636,8 @@ class ConditionTest(_ParserTestBase):
 
   def check_cond(self, condition, expected, **kwargs):
     out = "x: int" if expected else ""
+    if "version" not in kwargs:
+      kwargs["version"] = (3, 6, 5)
     self.check("""
       if %s:
         x = ...  # type: int
@@ -1648,55 +1650,55 @@ class ConditionTest(_ParserTestBase):
       """ % condition, 1, message)
 
   def test_version_eq(self):
-    self.check_cond("sys.version_info == (2, 7, 5)", False)
-    self.check_cond("sys.version_info == (2, 7, 6)", True)
-    self.check_cond("sys.version_info == (2, 7, 7)", False)
+    self.check_cond("sys.version_info == (3, 6, 4)", False)
+    self.check_cond("sys.version_info == (3, 6, 5)", True)
+    self.check_cond("sys.version_info == (3, 6, 6)", False)
 
   def test_version_ne(self):
-    self.check_cond("sys.version_info != (2, 7, 5)", True)
-    self.check_cond("sys.version_info != (2, 7, 6)", False)
-    self.check_cond("sys.version_info != (2, 7, 7)", True)
+    self.check_cond("sys.version_info != (3, 6, 4)", True)
+    self.check_cond("sys.version_info != (3, 6, 5)", False)
+    self.check_cond("sys.version_info != (3, 6, 6)", True)
 
   def test_version_lt(self):
-    self.check_cond("sys.version_info < (2, 7, 5)", False)
-    self.check_cond("sys.version_info < (2, 7, 6)", False)
-    self.check_cond("sys.version_info < (2, 7, 7)", True)
-    self.check_cond("sys.version_info < (2, 8, 0)", True)
+    self.check_cond("sys.version_info < (3, 6, 4)", False)
+    self.check_cond("sys.version_info < (3, 6, 5)", False)
+    self.check_cond("sys.version_info < (3, 6, 6)", True)
+    self.check_cond("sys.version_info < (3, 7, 0)", True)
 
   def test_version_le(self):
-    self.check_cond("sys.version_info <= (2, 7, 5)", False)
-    self.check_cond("sys.version_info <= (2, 7, 6)", True)
-    self.check_cond("sys.version_info <= (2, 7, 7)", True)
-    self.check_cond("sys.version_info <= (2, 8, 0)", True)
+    self.check_cond("sys.version_info <= (3, 6, 4)", False)
+    self.check_cond("sys.version_info <= (3, 6, 5)", True)
+    self.check_cond("sys.version_info <= (3, 6, 6)", True)
+    self.check_cond("sys.version_info <= (3, 7, 0)", True)
 
   def test_version_gt(self):
-    self.check_cond("sys.version_info > (2, 6, 0)", True)
-    self.check_cond("sys.version_info > (2, 7, 5)", True)
-    self.check_cond("sys.version_info > (2, 7, 6)", False)
-    self.check_cond("sys.version_info > (2, 7, 7)", False)
+    self.check_cond("sys.version_info > (3, 6, 0)", True)
+    self.check_cond("sys.version_info > (3, 6, 4)", True)
+    self.check_cond("sys.version_info > (3, 6, 5)", False)
+    self.check_cond("sys.version_info > (3, 6, 6)", False)
 
   def test_version_ge(self):
-    self.check_cond("sys.version_info >= (2, 6, 0)", True)
-    self.check_cond("sys.version_info >= (2, 7, 5)", True)
-    self.check_cond("sys.version_info >= (2, 7, 6)", True)
-    self.check_cond("sys.version_info >= (2, 7, 7)", False)
+    self.check_cond("sys.version_info >= (3, 6, 0)", True)
+    self.check_cond("sys.version_info >= (3, 6, 4)", True)
+    self.check_cond("sys.version_info >= (3, 6, 5)", True)
+    self.check_cond("sys.version_info >= (3, 6, 6)", False)
 
   def test_version_item(self):
-    self.check_cond("sys.version_info[0] == 2", True)
+    self.check_cond("sys.version_info[0] == 3", True)
 
   def test_version_slice(self):
-    self.check_cond("sys.version_info[:] == (2, 7, 6)", True)
-    self.check_cond("sys.version_info[:2] == (2, 7)", True)
-    self.check_cond("sys.version_info[2:] == (6,)", True)
-    self.check_cond("sys.version_info[0:1] == (2,)", True)
-    self.check_cond("sys.version_info[::] == (2, 7, 6)", True)
-    self.check_cond("sys.version_info[1::] == (7, 6)", True)
-    self.check_cond("sys.version_info[:2:] == (2, 7)", True)
-    self.check_cond("sys.version_info[::-2] == (6, 2)", True)
-    self.check_cond("sys.version_info[1:3:] == (7, 6)", True)
-    self.check_cond("sys.version_info[1::2] == (7,)", True)
-    self.check_cond("sys.version_info[:2:2] == (2,)", True)
-    self.check_cond("sys.version_info[3:1:-1] == (6,)", True)
+    self.check_cond("sys.version_info[:] == (3, 6, 5)", True)
+    self.check_cond("sys.version_info[:2] == (3, 6)", True)
+    self.check_cond("sys.version_info[2:] == (5,)", True)
+    self.check_cond("sys.version_info[0:1] == (3,)", True)
+    self.check_cond("sys.version_info[::] == (3, 6, 5)", True)
+    self.check_cond("sys.version_info[1::] == (6, 5)", True)
+    self.check_cond("sys.version_info[:2:] == (3, 6)", True)
+    self.check_cond("sys.version_info[::-2] == (5, 3)", True)
+    self.check_cond("sys.version_info[1:3:] == (6, 5)", True)
+    self.check_cond("sys.version_info[1::2] == (6,)", True)
+    self.check_cond("sys.version_info[:2:2] == (3,)", True)
+    self.check_cond("sys.version_info[3:1:-1] == (5,)", True)
 
   def test_version_shorter_tuples(self):
     self.check_cond("sys.version_info == (3,)", True, version=(3, 0, 0))
@@ -1772,30 +1774,30 @@ class PropertyDecoratorTest(_ParserTestBase):
 
   def test_property_with_type(self):
     expected = """
-      class A(object):
+      class A:
           name: str
     """
 
     # The return type of @property is used for the property type.
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str:...
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @name.setter
           def name(self, value: str) -> None: ...
       """, """
       from typing import Any
 
-      class A(object):
+      class A:
           name: Any
       """)
 
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str:...
 
@@ -1804,7 +1806,7 @@ class PropertyDecoratorTest(_ParserTestBase):
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str:...
 
@@ -1813,7 +1815,7 @@ class PropertyDecoratorTest(_ParserTestBase):
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str:...
 
@@ -1825,30 +1827,30 @@ class PropertyDecoratorTest(_ParserTestBase):
     expected = """
           from typing import Any
 
-          class A(object):
+          class A:
               name: Any
               """
 
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self): ...
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @name.setter
           def name(self, value): ...
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @name.deleter
           def name(self): ...
       """, expected)
 
     self.check("""
-      class A(object):
+      class A:
           @name.setter
           def name(self, value): ...
 
@@ -1895,7 +1897,7 @@ class PropertyDecoratorTest(_ParserTestBase):
 
   def test_property_getter(self):
     self.check("""
-      class A(object):
+      class A:
         @property
         def name(self) -> str: ...
 
@@ -1904,7 +1906,7 @@ class PropertyDecoratorTest(_ParserTestBase):
     """, """
     from typing import Union
 
-    class A(object):
+    class A:
         name: Union[str, int]
     """)
 
@@ -1913,17 +1915,17 @@ class MergeSignaturesTest(_ParserTestBase):
 
   def test_property(self):
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str: ...
       """, """
-      class A(object):
+      class A:
           name: str
       """)
 
   def test_merge_property_types(self):
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str: ...
 
@@ -1932,12 +1934,12 @@ class MergeSignaturesTest(_ParserTestBase):
       """, """
       from typing import Union
 
-      class A(object):
+      class A:
           name: Union[str, int]
       """)
 
     self.check("""
-      class A(object):
+      class A:
           @property
           def name(self) -> str: ...
 
@@ -1946,13 +1948,13 @@ class MergeSignaturesTest(_ParserTestBase):
     """, """
       from typing import Any
 
-      class A(object):
+      class A:
           name: Any
     """)
 
   def test_method(self):
     self.check("""
-      class A(object):
+      class A:
           def name(self) -> str: ...
       """)
 
@@ -1989,7 +1991,7 @@ class MergeSignaturesTest(_ParserTestBase):
 
   def test_classmethod(self):
     ast = self.check("""
-      class A(object):
+      class A:
           @classmethod
           def foo(x: int) -> str: ...
       """)
@@ -1997,7 +1999,7 @@ class MergeSignaturesTest(_ParserTestBase):
 
   def test_staticmethod(self):
     ast = self.check("""
-      class A(object):
+      class A:
           @staticmethod
           def foo(x: int) -> str: ...
       """)
@@ -2005,14 +2007,14 @@ class MergeSignaturesTest(_ParserTestBase):
 
   def test_new(self):
     ast = self.check("""
-      class A(object):
+      class A:
           def __new__(self) -> A: ...
       """)
     self.assertEqual("staticmethod", ast.classes[0].methods[0].kind)
 
   def test_abstractmethod(self):
     ast = self.check("""
-      class A(object):
+      class A:
           @abstractmethod
           def foo(x: int) -> str: ...
       """)
@@ -2021,7 +2023,7 @@ class MergeSignaturesTest(_ParserTestBase):
 
   def test_abstractmethod_manysignatures(self):
     ast = self.check("""
-      class A(object):
+      class A:
           @abstractmethod
           def foo(x: int) -> str: ...
           @abstractmethod
@@ -2029,7 +2031,7 @@ class MergeSignaturesTest(_ParserTestBase):
           @abstractmethod
           def foo(x: int, y: int, z: int) -> str: ...
       """, """
-      class A(object):
+      class A:
           @abstractmethod
           @overload
           def foo(x: int) -> str: ...
@@ -2056,7 +2058,7 @@ class MergeSignaturesTest(_ParserTestBase):
 class EntireFileTest(_ParserTestBase):
 
   def test_builtins(self):
-    self.check(get_builtins_source(self.PYTHON_VERSION), expected=IGNORE)
+    self.check(get_builtins_source(self.python_version), expected=IGNORE)
 
 
 class AnyTest(_ParserTestBase):
@@ -2087,7 +2089,7 @@ class AnyTest(_ParserTestBase):
 
 class CanonicalPyiTest(_ParserTestBase):
 
-  def testCanonicalVersion(self):
+  def test_canonical_version(self):
     src = textwrap.dedent("""
         from typing import Any
         def foo(x: int = 0) -> Any: ...
@@ -2102,7 +2104,7 @@ class CanonicalPyiTest(_ParserTestBase):
         def foo(x: str) -> Any: ...
     """).strip()
     self.assertMultiLineEqual(
-        parser.canonical_pyi(src, self.PYTHON_VERSION), expected)
+        parser.canonical_pyi(src, self.python_version), expected)
 
 
 class TypeMacroTest(_ParserTestBase):
@@ -2237,7 +2239,7 @@ class ImportTypeIgnoreTest(_ParserTestBase):
       from mod import attr  # type: ignore
       def f(x: attr) -> None: ...
     """)
-    ast = parser.parse_string(src, python_version=self.PYTHON_VERSION)
+    ast = parser.parse_string(src, python_version=self.python_version)
     self.assertTrue(ast.Lookup("attr"))
     self.assertTrue(ast.Lookup("f"))
 
@@ -2246,7 +2248,7 @@ class ImportTypeIgnoreTest(_ParserTestBase):
       from . import attr  # type: ignore
       def f(x: attr) -> None: ...
     """)
-    ast = parser.parse_string(src, python_version=self.PYTHON_VERSION)
+    ast = parser.parse_string(src, python_version=self.python_version)
     self.assertTrue(ast.Lookup("attr"))
     self.assertTrue(ast.Lookup("f"))
 
@@ -2255,7 +2257,7 @@ class ImportTypeIgnoreTest(_ParserTestBase):
       from .. import attr  # type: ignore
       def f(x: attr) -> None: ...
     """)
-    ast = parser.parse_string(src, python_version=self.PYTHON_VERSION)
+    ast = parser.parse_string(src, python_version=self.python_version)
     self.assertTrue(ast.Lookup("attr"))
     self.assertTrue(ast.Lookup("f"))
 
