@@ -325,6 +325,11 @@ class PrintVisitor(Visitor):
     split_result = (self._EscapedName(piece) for piece in split_name)
     return ".".join(split_result)
 
+  def _IsEmptyTuple(self, t):
+    """Check if it is an empty tuple."""
+    assert isinstance(t, pytd.GenericType)
+    return t.base_type == "tuple" and t.parameters == ("nothing",)
+
   def _NeedsTupleEllipsis(self, t):
     """Do we need to use Tuple[x, ...] instead of Tuple[x]?"""
     assert isinstance(t, pytd.GenericType)
@@ -465,9 +470,8 @@ class PrintVisitor(Visitor):
   def VisitClass(self, node):
     """Visit a class, producing a multi-line, properly indented string."""
     parents = node.parents
-    # If classobj is the only parent, then this is an old-style class, don't
-    # list any parents.
-    if parents == ("classobj",):
+    # If object is the only parent, we don't need to list any parents.
+    if parents == ("object",):
       parents = ()
     if node.metaclass is not None:
       parents += ("metaclass=" + node.metaclass,)
@@ -694,7 +698,9 @@ class PrintVisitor(Visitor):
   def VisitGenericType(self, node):
     """Convert a generic type to a string."""
     parameters = node.parameters
-    if self._NeedsTupleEllipsis(node):
+    if self._IsEmptyTuple(node):
+      parameters = ("()",)
+    elif self._NeedsTupleEllipsis(node):
       parameters += ("...",)
     elif self._NeedsCallableEllipsis(self.old_node):
       parameters = ("...",) + parameters[1:]
